@@ -15,26 +15,23 @@
    General Public License for more details.
 */
 
-#include"deepsolver.h"
+#include"deepsolver/deepsolver.h"
 #include"TransactionProgress.h"
 
-void TransactionProgress::onAvailablePkgListProcessing()
+DEEPSOLVER_BEGIN_NAMESPACE
+
+void TransactionProgress::onPkgListProcessingBegin()
 {
   if (m_suppress)
     return;
-  m_stream << "Processing package lists from all repositories" << std::endl;
+  m_stream << "Loading list of available packages...";
 }
 
-void TransactionProgress::onInstalledPkgListProcessing()
+void TransactionProgress::onPkgListProcessingEnd()
 {
   if (m_suppress)
     return;
-  m_stream << "Processing installed package list" << std::endl;
+  m_stream << " Done." << std::endl;
 }
 
-void TransactionProgress::onInstallRemovePkgListProcessing()
-{
-  if (m_suppress)
-    return;
-  m_stream << "Calculating package lists for installation and removing" << std::endl;
-}
+DEEPSOLVER_END_NAMESPACE
