@@ -15,10 +15,12 @@
    General Public License for more details.
 */
 
-#include"deepsolver.h"
-#include"OperationCore.h"
+#include"deepsolver/deepsolver.h"
+#include"deepsolver/OperationCore.h"
 #include"Messages.h"
 
+using namespace Deepsolver;
+
 int main(int argc, char* argv[])
 {
   messagesProgramName = "ds-conf";
