@@ -15,12 +15,14 @@
    General Public License for more details.
 */
 
-#include"deepsolver.h"
-#include"IndexCore.h"
+#include"deepsolver/deepsolver.h"
+#include"deepsolver/IndexCore.h"
 #include"CliParser.h"
 
 #define PREFIX "ds-provides:"
 
+using namespace Deepsolver;
+
 static RepoParams params;
 static CliParser cliParser;
 
