@@ -15,11 +15,13 @@
    General Public License for more details.
 */
 
-#include"deepsolver.h"
-#include"OperationCore.h"
+#include"deepsolver/deepsolver.h"
+#include"deepsolver/OperationCore.h"
 #include"TransactionProgress.h"
 #include"Messages.h"
 
+using namespace Deepsolver;
+
 static CliParser cliParser;
 static NamedPkgRel rel;
 
